const std = @import("std");
const batinfo = @import("batteryinfo.zig");

pub fn main() !void {
	var buffer: [65535]u8 = undefined;
	var fba = std.heap.FixedBufferAllocator.init(&buffer);
	const allocator = fba.allocator();

	const powerSupply = try std.fs.cwd().openDir("/sys/class/power_supply", .{});
	var i:u32 = 0;
	while(true) : (i += 1) {
		const name = try std.fmt.allocPrint(allocator, "BAT{}", .{i});
		defer allocator.free(name);
		const batDir = powerSupply.openDir(name, .{}) catch |err| switch(err) {
			error.FileNotFound => {return;},
			else => {return err;},
		};
		const battery = try batinfo.GetBatteryInfoAlloc(allocator, batDir);
		defer battery.deinit();
		try printBattery(battery);
	}
}

fn printBattery(battery: batinfo.BatteryInfo) !void {
	const stdout = std.io.getStdOut().writer();
	try stdout.print("Battery {s} {s} ({s})\n", .{battery.Manufacturer, battery.Model, battery.Status});
	try stdout.print("\tTechnology:           {s}\n", .{battery.Technology});
	try stdout.print("\tCell series count:    {}s (guessed)\n\n", .{battery.CellSeriesCount});
	try stdout.print("\tCapacity:             {}%\n", .{battery.Capacity});
	try stdout.print("\tCapacity (design):    {}%\n", .{battery.CapacityDesign});
	try stdout.print("\tVmin:                 {d:.2}V  Per cell: {d:.2}V\n", .{battery.Vmin, battery.Vmin/@as(f32, @floatFromInt(battery.CellSeriesCount))});
	try stdout.print("\tVnow:                 {d:.2}V  Per cell: {d:.2}V\n", .{battery.Vnow, battery.Vnow/@as(f32, @floatFromInt(battery.CellSeriesCount))});
	try stdout.print("\tCharge now:           {}mAh\n", .{battery.ChargeNow});
	try stdout.print("\tCharge full:          {}mAh\n", .{battery.ChargeFull});
	try stdout.print("\tCharge full (design): {}mAh\n\n", .{battery.ChargeFullDesign});
}
